CockpitAutomationTargetResource class final

Constructors

CockpitAutomationTargetResource({required String targetId, required String workspaceId, required String platform, required String deviceId, required CockpitTargetKind targetKind, required CockpitAutomationTargetMode mode, required CockpitAutomationTargetEnvironment environment, String? entrypoint, String? entrypointSha256, String? flavor, String? appId, String? sessionId})
Creates a CockpitAutomationTargetResource.
CockpitAutomationTargetResource.fromJson(Object? value, {String path = r'$', CockpitDecodePolicy decodePolicy = CockpitDecodePolicy.requests})
Decodes a CockpitAutomationTargetResource from a JSON object.
factory

Properties

appId String?
final
deviceId String
final
entrypoint String?
final
entrypointSha256 String?
final
environment CockpitAutomationTargetEnvironment
final
flavor String?
final
hashCode int
The hash code for this object.
no setterinherited
mode CockpitAutomationTargetMode
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
targetId String
final
targetKind CockpitTargetKind
final
workspaceId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Encodes this CockpitAutomationTargetResource as a JSON object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited