CockpitRemoteBridgeResponse class final

Constructors

CockpitRemoteBridgeResponse({required String requestId, required int statusCode, String contentType = 'application/json', Map<String, Object?>? jsonBody, String? bytesBase64})
Creates a CockpitRemoteBridgeResponse.
const
CockpitRemoteBridgeResponse.fromEndpointResponse({required String requestId, required CockpitRemoteSessionEndpointResponse response})
Creates a CockpitRemoteBridgeResponse using the named constructor fromEndpointResponse.
factory
CockpitRemoteBridgeResponse.fromJson(Map<String, Object?> json)
Decodes a CockpitRemoteBridgeResponse from a JSON object.
factory

Properties

binaryBody → List<int>?
no setter
bytesBase64 → String?
final
contentType → String
final
hashCode → int
The hash code for this object.
no setterinherited
jsonBody → Map<String, Object?>?
final
requestId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Encodes this CockpitRemoteBridgeResponse as a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited