CockpitRemoteSessionEndpointRequest class final

Constructors

CockpitRemoteSessionEndpointRequest({required String method, required Uri uri, Map<String, Object?> jsonBody = const <String, Object?>{}})
Creates a CockpitRemoteSessionEndpointRequest.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonBody → Map<String, Object?>
final
method → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited