CockpitRemoteSessionEndpointResponse class final
Constructors
-
CockpitRemoteSessionEndpointResponse.binary(List<
int> bytes, {int statusCode = 200, String contentType = 'application/octet-stream'}) -
Creates a CockpitRemoteSessionEndpointResponse using the named constructor
binary.const - CockpitRemoteSessionEndpointResponse.binaryFile(String sourceFilePath, {int statusCode = 200, String contentType = 'application/octet-stream'})
-
Creates a CockpitRemoteSessionEndpointResponse using the named constructor
binaryFile.const -
CockpitRemoteSessionEndpointResponse.json(Map<
String, Object?> body, {int statusCode = 200}) -
Creates a CockpitRemoteSessionEndpointResponse using the named constructor
json.const
Properties
-
binaryBody
→ List<
int> ? -
final
- contentType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jsonBody
→ Map<
String, Object?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceFilePath → String?
-
final
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited