CockpitSnapshotSummary class final
Constructors
- CockpitSnapshotSummary({required int visibleTargetCount, required int targetsWithCockpitIdCount, required int targetsWithTextCount, required bool styleDetailsIncluded, required bool diagnosticPropertiesIncluded, required bool ancestorSummariesIncluded, required bool rebuildSummaryIncluded, required bool accessibilitySummaryIncluded})
-
Creates a CockpitSnapshotSummary.
const
-
CockpitSnapshotSummary.fromJson(Map<
String, Object?> json) -
Decodes a CockpitSnapshotSummary from a JSON object.
factory
Properties
- accessibilitySummaryIncluded → bool
-
final
- ancestorSummariesIncluded → bool
-
final
- diagnosticPropertiesIncluded → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- rebuildSummaryIncluded → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleDetailsIncluded → bool
-
final
- targetsWithCockpitIdCount → int
-
final
- targetsWithTextCount → int
-
final
- visibleTargetCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Encodes this CockpitSnapshotSummary as a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override